==> libisfreetype-java_5.2.20091102.orig.tar.gz: libisfreetype-java-5.2.20091102/src/de/intarsys/cwt/freetype/Library.java <==
/*
 * Copyright (c) 2008, intarsys consulting GmbH
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * - Neither the name of intarsys nor the names of its contributors may be used
 *   to endorse or promote products derived from this software without specific
 *   prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package de.intarsys.cwt.freetype;

import java.nio.ByteBuffer;

import de.intarsys.cwt.freetype.nativec.FTFace;
import de.intarsys.cwt.freetype.nativec.FTLibrary;
import de.intarsys.cwt.freetype.nativec._FTNI;
import de.intarsys.nativec.type.NativeBuffer;
import de.intarsys.nativec.type.NativeReference;

public class Library {

	private _FTNI ftni;

	private FTLibrary library;

	protected Library(_FTNI paramFtni, FTLibrary paramLibrary) {
		ftni = paramFtni;
		library = paramLibrary;
	}

	public void doneFreeType() {
		ftni.DoneFreeType(library);
	}

	public FTLibrary getLibrary() {
		return library;
	}

	public Face newFace(String name, int index) {
		NativeReference refFace = NativeReference.create(FTFace.META);
		int rc = ftni.NewFace(library, name, index, refFace);
		if (rc != 0) {
			return null;
		}
		return new Face(ftni, (FTFace) refFace.getValue(), null);
	}

	public Face newMemoryFace(ByteBuffer fontdata, int index) {
		NativeReference refFace = NativeReference.create(FTFace.META);
		NativeBuffer nativeBuffer = new NativeBuffer(fontdata);
		int rc = ftni.NewMemoryFace(library, nativeBuffer, index, refFace);
		if (rc != 0) {
			return null;
		}
		return new Face(ftni, (FTFace) refFace.getValue(), nativeBuffer);
	}

}

==> libisfreetype-java_5.3.20100629.orig.tar.gz: libisfreetype-java-5.3.20100629/src/de/intarsys/cwt/freetype/Library.java <==
/*
 * Copyright (c) 2008, intarsys consulting GmbH
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * - Neither the name of intarsys nor the names of its contributors may be used
 *   to endorse or promote products derived from this software without specific
 *   prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package de.intarsys.cwt.freetype;

import de.intarsys.cwt.freetype.nativec.FTFace;
import de.intarsys.cwt.freetype.nativec.FTLibrary;
import de.intarsys.cwt.freetype.nativec._FTNI;
import de.intarsys.nativec.type.NativeBuffer;
import de.intarsys.nativec.type.NativeReference;

public class Library {

	private _FTNI ftni;

	private FTLibrary library;

	protected Library(_FTNI paramFtni, FTLibrary paramLibrary) {
		ftni = paramFtni;
		library = paramLibrary;
	}

	public void doneFreeType() {
		ftni.DoneFreeType(library);
	}

	public FTLibrary getLibrary() {
		return library;
	}

	public Face newFace(String name, int index) {
		NativeReference refFace = NativeReference.create(FTFace.META);
		int rc = ftni.NewFace(library, name, index, refFace);
		if (rc != 0) {
			return null;
		}
		return new Face(ftni, (FTFace) refFace.getValue(), null);
	}

	public Face newMemoryFace(byte[] fontdata, int index) {
		NativeReference refFace = NativeReference.create(FTFace.META);
		NativeBuffer nativeBuffer = new NativeBuffer(fontdata);
		int rc = ftni.NewMemoryFace(library, nativeBuffer, index, refFace);
		if (rc != 0) {
			return null;
		}
		return new Face(ftni, (FTFace) refFace.getValue(), nativeBuffer);
	}

}
